diff -ur nginx-1.1.12-old/src/http/modules/ngx_http_xslt_filter_module.c nginx-1.1.12/src/http/modules/ngx_http_xslt_filter_module.c
--- nginx-1.1.12-old/src/http/modules/ngx_http_xslt_filter_module.c	2010-07-12 14:52:01.000000000 +0200
+++ nginx-1.1.12/src/http/modules/ngx_http_xslt_filter_module.c	2012-01-02 19:03:40.000000000 +0100
@@ -40,14 +40,17 @@
 typedef struct {
     xsltStylesheetPtr    stylesheet;
     ngx_array_t          params;       /* ngx_http_complex_value_t */
+    ngx_str_t		 name;
 } ngx_http_xslt_sheet_t;
 
 
 typedef struct {
+    ngx_flag_t		 use_root;     /* use root as prefix for xslt_stylesheet */
     xmlDtdPtr            dtd;
     ngx_array_t          sheets;       /* ngx_http_xslt_sheet_t */
     ngx_hash_t           types;
     ngx_array_t         *types_keys;
+    ngx_array_t          params;       /* ngx_http_complex_value_t */
 } ngx_http_xslt_filter_loc_conf_t;
 
 
@@ -84,16 +87,18 @@
     void *conf);
 static char *ngx_http_xslt_stylesheet(ngx_conf_t *cf, ngx_command_t *cmd,
     void *conf);
+static char *ngx_http_xslt_stylesheet_param(ngx_conf_t *cf, ngx_command_t *cmd,
+    void *conf);
 static void ngx_http_xslt_cleanup_dtd(void *data);
 static void ngx_http_xslt_cleanup_stylesheet(void *data);
 static void *ngx_http_xslt_filter_create_main_conf(ngx_conf_t *cf);
 static void *ngx_http_xslt_filter_create_conf(ngx_conf_t *cf);
 static char *ngx_http_xslt_filter_merge_conf(ngx_conf_t *cf, void *parent,
     void *child);
+    static ngx_int_t ngx_http_xslt_filter_preinit(ngx_conf_t *cf);
 static ngx_int_t ngx_http_xslt_filter_init(ngx_conf_t *cf);
 static void ngx_http_xslt_filter_exit(ngx_cycle_t *cycle);
 
-
 ngx_str_t  ngx_http_xslt_default_types[] = {
     ngx_string("text/xml"),
     ngx_null_string
@@ -109,6 +114,13 @@
       0,
       NULL },
 
+    { ngx_string("xslt_use_root"),
+      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_FLAG,
+      ngx_conf_set_flag_slot,
+      NGX_HTTP_LOC_CONF_OFFSET,
+      offsetof(ngx_http_xslt_filter_loc_conf_t, use_root),
+      NULL },
+
     { ngx_string("xslt_stylesheet"),
       NGX_HTTP_LOC_CONF|NGX_CONF_1MORE,
       ngx_http_xslt_stylesheet,
@@ -116,6 +128,13 @@
       0,
       NULL },
 
+    { ngx_string("xslt_stylesheet_param"),
+      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_TAKE1,
+      ngx_http_xslt_stylesheet_param,
+      NGX_HTTP_LOC_CONF_OFFSET,
+      0,
+      NULL },
+
     { ngx_string("xslt_types"),
       NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_1MORE,
       ngx_http_types_slot,
@@ -128,7 +147,7 @@
 
 
 static ngx_http_module_t  ngx_http_xslt_filter_module_ctx = {
-    NULL,                                  /* preconfiguration */
+    ngx_http_xslt_filter_preinit,          /* preconfiguration */
     ngx_http_xslt_filter_init,             /* postconfiguration */
 
     ngx_http_xslt_filter_create_main_conf, /* create main configuration */
@@ -764,12 +783,9 @@
 
     ngx_str_t                         *value;
     ngx_uint_t                         i, n;
-    ngx_pool_cleanup_t                *cln;
-    ngx_http_xslt_file_t              *file;
     ngx_http_xslt_sheet_t             *sheet;
     ngx_http_complex_value_t          *param;
     ngx_http_compile_complex_value_t   ccv;
-    ngx_http_xslt_filter_main_conf_t  *xmcf;
 
     value = cf->args->elts;
 
@@ -789,45 +805,8 @@
 
     ngx_memzero(sheet, sizeof(ngx_http_xslt_sheet_t));
 
-    if (ngx_conf_full_name(cf->cycle, &value[1], 0) != NGX_OK) {
-        return NGX_CONF_ERROR;
-    }
-
-    xmcf = ngx_http_conf_get_module_main_conf(cf, ngx_http_xslt_filter_module);
-
-    file = xmcf->sheet_files.elts;
-    for (i = 0; i < xmcf->sheet_files.nelts; i++) {
-        if (ngx_strcmp(file[i].name, &value[1].data) == 0) {
-            sheet->stylesheet = file[i].data;
-            goto found;
-        }
-    }
-
-    cln = ngx_pool_cleanup_add(cf->pool, 0);
-    if (cln == NULL) {
-        return NGX_CONF_ERROR;
-    }
-
-    sheet->stylesheet = xsltParseStylesheetFile(value[1].data);
-    if (sheet->stylesheet == NULL) {
-        ngx_conf_log_error(NGX_LOG_ERR, cf, 0,
-                           "xsltParseStylesheetFile(\"%s\") failed",
-                           value[1].data);
-        return NGX_CONF_ERROR;
-    }
-
-    cln->handler = ngx_http_xslt_cleanup_stylesheet;
-    cln->data = sheet->stylesheet;
-
-    file = ngx_array_push(&xmcf->sheet_files);
-    if (file == NULL) {
-        return NGX_CONF_ERROR;
-    }
-
-    file->name = value[1].data;
-    file->data = sheet->stylesheet;
-
-found:
+    sheet->name.len  = value[1].len;
+    sheet->name.data = value[1].data;
 
     n = cf->args->nelts;
 
@@ -864,6 +843,43 @@
     return NGX_CONF_OK;
 }
 
+static char *
+ngx_http_xslt_stylesheet_param(ngx_conf_t *cf, ngx_command_t *cmd, void *conf)
+{
+    ngx_http_xslt_filter_loc_conf_t *xlcf = conf;
+    ngx_http_complex_value_t          *param;
+    ngx_http_compile_complex_value_t   ccv;
+    ngx_str_t                         *value;
+
+    value = cf->args->elts;
+
+    /* alloc array */
+    if (xlcf->params.elts == NULL
+    	&& ngx_array_init(&xlcf->params, cf->pool, 1, sizeof(ngx_http_complex_value_t))
+        != NGX_OK)
+    {
+        return NGX_CONF_ERROR;
+    }
+
+    param = ngx_array_push(&xlcf->params);
+    if (param == NULL) {
+        return NGX_CONF_ERROR;
+    }
+
+    ngx_memzero(&ccv, sizeof(ngx_http_compile_complex_value_t));
+
+    ccv.cf = cf;
+    ccv.value = &value[1];
+    ccv.complex_value = param;
+    ccv.zero = 1;
+
+    if (ngx_http_compile_complex_value(&ccv) != NGX_OK) {
+       return NGX_CONF_ERROR;
+    }
+
+    return NGX_CONF_OK;
+}
+
 
 static void
 ngx_http_xslt_cleanup_dtd(void *data)
@@ -926,6 +942,8 @@
      *     conf->types_keys = NULL;
      */
 
+    conf->use_root = NGX_CONF_UNSET;
+
     return conf;
 }
 
@@ -933,8 +951,33 @@
 static char *
 ngx_http_xslt_filter_merge_conf(ngx_conf_t *cf, void *parent, void *child)
 {
+    ngx_uint_t pi = 0;
     ngx_http_xslt_filter_loc_conf_t *prev = parent;
     ngx_http_xslt_filter_loc_conf_t *conf = child;
+    ngx_http_xslt_sheet_t *sheet = NULL;
+    ngx_http_xslt_filter_main_conf_t *xmcf = NULL;
+    ngx_http_core_loc_conf_t *clcf = NULL;
+    ngx_http_complex_value_t *params = prev->params.elts;
+
+    ngx_conf_merge_value(conf->use_root, prev->use_root, 0);
+
+    if(prev->params.nelts && !conf->params.nelts &&
+        ngx_array_init(&conf->params, cf->pool, prev->params.nelts, sizeof(ngx_http_complex_value_t))
+        != NGX_OK) {
+        return NGX_CONF_ERROR;
+    }
+    for(pi = 0; pi < prev->params.nelts; pi++)
+    {
+        ngx_http_complex_value_t *new = ngx_array_push(&conf->params);
+        if (new == NULL) {
+            return NGX_CONF_ERROR;
+        }
+    	*new = params[pi];
+    }
+    params = conf->params.elts;
+
+    xmcf = ngx_http_conf_get_module_main_conf(cf, ngx_http_xslt_filter_module);
+    clcf = ngx_http_conf_get_module_loc_conf(cf, ngx_http_core_module);
 
     if (conf->dtd == NULL) {
         conf->dtd = prev->dtd;
@@ -943,6 +986,86 @@
     if (conf->sheets.nelts == 0) {
         conf->sheets = prev->sheets;
     }
+    else
+    {
+        ngx_uint_t i = 0, ii = 0;
+        ngx_http_xslt_file_t *file = NULL;
+
+        sheet = conf->sheets.elts;
+        for (i = 0; i < conf->sheets.nelts; i++)
+        {
+            /* use root as prefix if enabled
+            	and root contains no variable */
+            if(conf->use_root == 1
+            	&& sheet[i].name.len && clcf->root.len
+            	&& sheet[i].name.data[0] != '/'
+            	&& ngx_strchr(clcf->root.data, '$') == NULL) {
+
+                 u_char *s = sheet[i].name.data;
+
+                 sheet[i].name.data = ngx_pcalloc(cf->pool, sheet[i].name.len + 1 + clcf->root.len + 1);
+                 if(sheet[i].name.data == NULL) {
+                     return NGX_CONF_ERROR;
+                 }
+
+                 ngx_sprintf(sheet[i].name.data, "%s/%s", clcf->root.data, s);
+            } else if (ngx_conf_full_name(cf->cycle, &sheet[i].name, 0) != NGX_OK) {
+                 return NGX_CONF_ERROR;
+            }
+
+	    file = xmcf->sheet_files.elts;
+            for (ii = 0; ii < xmcf->sheet_files.nelts; ii++)
+            {
+                if (ngx_strcmp(file[ii].name, sheet[i].name.data) == 0)
+                {
+                     sheet[i].stylesheet = file[ii].data;
+                }
+            }
+
+            if(!sheet[i].stylesheet)
+            {
+                ngx_pool_cleanup_t *cln = NULL;
+
+                cln = ngx_pool_cleanup_add(cf->pool, 0);
+                if (cln == NULL) {
+                     return NGX_CONF_ERROR;
+                }
+
+                sheet[i].stylesheet = xsltParseStylesheetFile(sheet[i].name.data);
+                if (sheet[i].stylesheet == NULL) {
+                     ngx_conf_log_error(NGX_LOG_ERR, cf, 0,
+                                        "xsltParseStylesheetFile(\"%s\") failed",
+                                        sheet[i].name.data);
+                      return NGX_CONF_ERROR;
+                 }
+
+                 cln->handler = ngx_http_xslt_cleanup_stylesheet;
+                 cln->data = sheet[i].stylesheet;
+
+                 file = ngx_array_push(&xmcf->sheet_files);
+                 if (file == NULL) {
+                     return NGX_CONF_ERROR;
+                 }
+
+                 file->name = sheet[i].name.data;
+                 file->data = sheet[i].stylesheet;
+            }
+
+	    if(conf->params.nelts && !sheet[i].params.nelts
+                 && ngx_array_init(&sheet[i].params, cf->pool, conf->params.nelts, sizeof(ngx_http_complex_value_t))
+                 != NGX_OK) {
+                return NGX_CONF_ERROR;
+            }
+            for(pi = 0; pi < conf->params.nelts; pi++)
+            {
+                 ngx_http_complex_value_t *new = ngx_array_push(&sheet[i].params);
+                 if (new == NULL) {
+                     return NGX_CONF_ERROR;
+                 }
+                 *new = params[pi];
+            }
+        }
+    }
 
     if (ngx_http_merge_types(cf, &conf->types_keys, &conf->types,
                              &prev->types_keys, &prev->types,
@@ -955,9 +1078,8 @@
     return NGX_CONF_OK;
 }
 
-
 static ngx_int_t
-ngx_http_xslt_filter_init(ngx_conf_t *cf)
+ngx_http_xslt_filter_preinit(ngx_conf_t *cf)
 {
     xmlInitParser();
 
@@ -965,6 +1087,12 @@
     exsltRegisterAll();
 #endif
 
+    return NGX_OK;
+}
+
+static ngx_int_t
+ngx_http_xslt_filter_init(ngx_conf_t *cf)
+{
     ngx_http_next_header_filter = ngx_http_top_header_filter;
     ngx_http_top_header_filter = ngx_http_xslt_header_filter;
 
@@ -974,7 +1102,6 @@
     return NGX_OK;
 }
 
-
 static void
 ngx_http_xslt_filter_exit(ngx_cycle_t *cycle)
 {